@@ -3,6 +3,7 @@ import logging
 from .constants import constants, BASE_URL
 from .base import Base
 
+
 def get_overview_chartdata(timePeriod='one_month'):
     """Returns chartdata from overview page
 
@@ -22,6 +23,7 @@ def get_overview_chartdata(timePeriod='one_month'):
     else:
         raise Exception("Invalid timePeriod!")
 
+
 def get_distribution_chartdata():
     """Returns values from account distribution chart
 
@@ -31,15 +33,17 @@ def get_distribution_chartdata():
     Note:
         Authentication necessary
     """
-    return Base()._request(f"{BASE_URL}{constants['paths']['CHARTDATA_DISTRIBUTION']}", auth=True)
+    url = f"{BASE_URL}{constants['paths']['CHARTDATA_DISTRIBUTION']}"
+    return Base()._request(url, auth=True)
+
 
 def get_ticker_chartdata(orderbookId, timePeriod='today'):
     """Returns chartdata of ticker
-    
+
     Args:
         orderbookId (int): id of instrument
         timePeriod (str): time period
-    
+
     Returns:
         dict:
     """
