@@ -3,16 +3,6 @@ import logging
 from .constants import constants, BASE_URL
 from .base import Base
 
-def search(searchQuery):
-    """Returns results of search query
-
-    Args:
-        searchQuery (str): The string to be searched at Avanza
-    
-    Returns:
-        dict:
-    """
-    return Base()._request(f"{BASE_URL}{constants['paths']['SEARCH']}".format(searchQuery))
 
 def get_news(index=5):
     """Returns x amount of news
@@ -29,6 +19,7 @@ def get_news(index=5):
     except ValueError:
         logging.error("index must be int")
 
+
 def get_account_overview(accountId):
     """Returns information about accounts watchlists
     
@@ -43,10 +34,12 @@ def get_account_overview(accountId):
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['ACCOUNT_OVERVIEW_PATH']}".format(accountId), auth=True)
 
+
 def get_transactions(accountId=None):
     """
     Returns information about accounts watchlists
 
+
     Args:
         accountId (int, optional): id of account
     
@@ -61,6 +54,7 @@ def get_transactions(accountId=None):
         return Base()._request(url.format(accountId), auth=True)
     return Base()._request(url.replace('{0:d}', ''), auth=True)
 
+
 def get_insight(timePeriod="today"):
     """
     Returns accounts
@@ -81,6 +75,7 @@ def get_insight(timePeriod="today"):
     else:
         raise Exception("Invalid timePeriod!")
 
+
 def get_watchlists():
     """Returns information about accounts watchlists
     
@@ -92,6 +87,7 @@ def get_watchlists():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['WATCHLISTS_PATH']}", auth=True)
 
+
 def get_positions():
     """Returns information about accounts positions
     
@@ -103,6 +99,7 @@ def get_positions():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['POSITIONS_PATH']}", auth=True)
 
+
 def get_deals_and_orders():
     """Returns deals, orders and accounts
     
@@ -114,6 +111,7 @@ def get_deals_and_orders():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['DEALS_AND_ORDERS_PATH']}", auth=True)
 
+
 def get_feed():
     """Returns feed from Home
     
@@ -125,6 +123,7 @@ def get_feed():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['FEED']}", auth=True)
 
+
 def get_accounts():
     """Returns accounts
     
@@ -136,6 +135,7 @@ def get_accounts():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['ACCOUNTS']}", auth=True)
 
+
 def get_inspiration_list():
     """Returns inspiration list
     
@@ -147,12 +147,12 @@ def get_inspiration_list():
     """
     return Base()._request(f"{BASE_URL}{constants['paths']['INSPIRATION_LIST_PATH']}")
 
+
 def get_account_summary():
     """Returns account summary
     
     Returns:
         dict:
-    
     Note:
         Authentication neccessary
     """
